@@ -20,12 +20,13 @@ use sequoia_openpgp::{
     },
     policy::Policy,
     serialize::{
-        stream::{Armorer, Encryptor, LiteralWriter, Message, Signer},
+        stream::{Armorer, Encryptor2, LiteralWriter, Message, Signer},
         Serialize,
     },
     types::{RevocationStatus, SymmetricAlgorithm},
     Cert, KeyHandle,
 };
+use zeroize::Zeroize;
 
 pub use crate::error::{Error, Result};
 use crate::{
@@ -188,10 +189,13 @@ pub trait Crypto {
         valid_signing_keys: &[[u8; 20]],
     ) -> std::result::Result<SignatureStatus, VerificationError>;
 
+    /// Returns true if a recipient is in the users keyring.
+    fn is_key_in_keyring(&self, recipient: &Recipient) -> Result<bool>;
+
     /// Pull keys from the keyserver for those recipients.
     /// # Errors
     /// Will return `Err` on network errors and similar.
-    fn pull_keys(&mut self, recipients: &[Recipient], config_path: &Path) -> Result<String>;
+    fn pull_keys(&mut self, recipients: &[&Recipient], config_path: &Path) -> Result<String>;
 
     /// Import a key from text.
     /// # Errors
@@ -224,7 +228,9 @@ impl Crypto for GpgMe {
         let mut ctx = gpgme::Context::from_protocol(gpgme::Protocol::OpenPgp)?;
         let mut output = Vec::new();
         ctx.decrypt(ciphertext, &mut output)?;
-        Ok(String::from_utf8(output)?)
+        let result = String::from_utf8(output.to_vec())?;
+        output.zeroize();
+        Ok(result)
     }
 
     fn encrypt_string(&self, plaintext: &str, recipients: &[Recipient]) -> Result<Vec<u8>> {
@@ -246,7 +252,6 @@ impl Crypto for GpgMe {
             &mut output,
             gpgme::EncryptFlags::NO_COMPRESS,
         )?;
-
         Ok(output)
     }
 
@@ -340,7 +345,17 @@ impl Crypto for GpgMe {
         }
     }
 
-    fn pull_keys(&mut self, recipients: &[Recipient], _config_path: &Path) -> Result<String> {
+    fn is_key_in_keyring(&self, recipient: &Recipient) -> Result<bool> {
+        let mut ctx = gpgme::Context::from_protocol(gpgme::Protocol::OpenPgp)?;
+
+        if let Some(fingerprint) = recipient.fingerprint {
+            Ok(ctx.get_key(hex::encode(fingerprint)).is_ok())
+        } else {
+            Ok(false)
+        }
+    }
+
+    fn pull_keys(&mut self, recipients: &[&Recipient], _config_path: &Path) -> Result<String> {
         let mut ctx = gpgme::Context::from_protocol(gpgme::Protocol::OpenPgp)?;
 
         let mut result_str = String::new();
@@ -434,7 +449,7 @@ struct Helper<'a> {
     /// This is all the certificates that are allowed to sign something
     public_keys: Vec<Arc<sequoia_openpgp::Cert>>,
     /// context if talking to gpg_agent for example
-    ctx: Option<sequoia_ipc::gnupg::Context>,
+    ctx: Option<sequoia_gpg_agent::gnupg::Context>,
     /// to do verification or not
     do_signature_verification: bool,
 }
@@ -507,10 +522,11 @@ impl<'a> DecryptionHelper for Helper<'a> {
         if self.secret.is_none() {
             // we don't know which key is the users own key, so lets try them all
 
+            let mut selected_fingerprint: Option<sequoia_openpgp::Fingerprint> = None;
             for pkesk in pkesks {
                 if let Ok(cert) = find(self.key_ring, pkesk.recipient()) {
                     let key = cert.primary_key();
-                    let mut pair = sequoia_ipc::gnupg::KeyPair::new(
+                    let mut pair = sequoia_gpg_agent::gnupg::KeyPair::new(
                         self.ctx
                             .as_ref()
                             .ok_or_else(|| anyhow::anyhow!("no context configured"))?,
@@ -520,14 +536,13 @@ impl<'a> DecryptionHelper for Helper<'a> {
                         .decrypt(&mut pair, sym_algo)
                         .map_or(false, |(algo, session_key)| decrypt(algo, &session_key))
                     {
+                        selected_fingerprint = Some(cert.fingerprint());
                         break;
                     }
                 }
             }
 
-            // XXX: In production code, return the Fingerprint of the
-            // recipient's Cert here
-            return Ok(None);
+            return Ok(selected_fingerprint);
         }
         // The encryption key is the first and only subkey.
         let key = self
@@ -545,13 +560,21 @@ impl<'a> DecryptionHelper for Helper<'a> {
         // The secret key is not encrypted.
         let mut pair = key.into_keypair()?;
 
-        pkesks[0]
-            .decrypt(&mut pair, sym_algo)
-            .map(|(algo, session_key)| decrypt(algo, &session_key));
+        for pkesk in pkesks {
+            if pkesk
+                .decrypt(&mut pair, sym_algo)
+                .map(|(algo, sk)| decrypt(algo, &sk))
+                .unwrap_or(false)
+            {
+                return Ok(Some(
+                    self.secret
+                        .ok_or_else(|| anyhow::anyhow!("no user secret"))?
+                        .fingerprint(),
+                ));
+            }
+        }
 
-        // XXX: In production code, return the Fingerprint of the
-        // recipient's Cert here
-        Ok(None)
+        Err(anyhow::anyhow!("no pkesks managed to descrypt ciphertext"))
     }
 }
 
@@ -601,13 +624,15 @@ pub struct Sequoia {
     user_key_id: [u8; 20],
     /// All certs in the keys directory
     key_ring: HashMap<[u8; 20], Arc<sequoia_openpgp::Cert>>,
+    /// The home directory of the user, for gnupg context
+    user_home: std::path::PathBuf,
 }
 
 impl Sequoia {
     /// creates the sequoia object
     /// # Errors
     /// If there is any problems reading the keys directory
-    pub fn new(config_path: &Path, own_fingerprint: [u8; 20]) -> Result<Self> {
+    pub fn new(config_path: &Path, own_fingerprint: [u8; 20], user_home: &Path) -> Result<Self> {
         let mut key_ring: HashMap<[u8; 20], Arc<sequoia_openpgp::Cert>> = HashMap::new();
 
         let dir = config_path.join("share").join("ripasso").join("keys");
@@ -628,9 +653,22 @@ impl Sequoia {
         Ok(Self {
             user_key_id: own_fingerprint,
             key_ring,
+            user_home: user_home.to_path_buf(),
         })
     }
 
+    pub fn from_values(
+        user_key_id: [u8; 20],
+        key_ring: HashMap<[u8; 20], Arc<sequoia_openpgp::Cert>>,
+        user_home: &Path,
+    ) -> Self {
+        Self {
+            user_key_id,
+            key_ring,
+            user_home: user_home.to_path_buf(),
+        }
+    }
+
     /// Converts a list of recipients to their sequoia certs
     /// # Errors
     /// errors if not all recipients have certs
@@ -714,13 +752,15 @@ impl Crypto for Sequoia {
             };
 
             // Now, create a decryptor with a helper using the given Certs.
-            let mut decryptor =
-                DecryptorBuilder::from_bytes(ciphertext)?.with_policy(&p, None, helper)?;
+            let mut decryptor = DecryptorBuilder::from_bytes(ciphertext)?
+                .with_policy(&p, None, helper)
+                .unwrap();
 
             // Decrypt the data.
-            std::io::copy(&mut decryptor, &mut sink)?;
-
-            Ok(std::str::from_utf8(&sink)?.to_owned())
+            std::io::copy(&mut decryptor, &mut sink).unwrap();
+            let result = std::str::from_utf8(&sink).unwrap().to_owned();
+            sink.zeroize();
+            Ok(result)
         } else {
             // Make a helper that that feeds the recipient's secret key to the
             // decryptor.
@@ -729,7 +769,10 @@ impl Crypto for Sequoia {
                 secret: Some(decrypt_key),
                 key_ring: &self.key_ring,
                 public_keys: vec![],
-                ctx: Some(sequoia_ipc::gnupg::Context::with_homedir("/home/capitol/")?),
+                ctx: Some(
+                    sequoia_gpg_agent::gnupg::Context::with_homedir(&self.user_home)
+                        .map_err(anyhow::Error::from)?,
+                ),
                 do_signature_verification: false,
             };
 
@@ -739,8 +782,9 @@ impl Crypto for Sequoia {
 
             // Decrypt the data.
             std::io::copy(&mut decryptor, &mut sink)?;
-
-            Ok(std::str::from_utf8(&sink)?.to_owned())
+            let result = std::str::from_utf8(&sink)?.to_owned();
+            sink.zeroize();
+            Ok(result)
         }
     }
 
@@ -768,7 +812,7 @@ impl Crypto for Sequoia {
         let message = Message::new(&mut sink);
 
         // We want to encrypt a literal data packet.
-        let message = Encryptor::for_recipients(message, recipient_keys).build()?;
+        let message = Encryptor2::for_recipients(message, recipient_keys).build()?;
 
         // Emit a literal data packet.
         let mut message = LiteralWriter::new(message).build()?;
@@ -874,7 +918,15 @@ impl Crypto for Sequoia {
         Ok(SignatureStatus::Good)
     }
 
-    fn pull_keys(&mut self, recipients: &[Recipient], config_path: &Path) -> Result<String> {
+    fn is_key_in_keyring(&self, recipient: &Recipient) -> Result<bool> {
+        if let Some(fingerprint) = recipient.fingerprint {
+            Ok(self.key_ring.contains_key(&fingerprint))
+        } else {
+            Ok(false)
+        }
+    }
+
+    fn pull_keys(&mut self, recipients: &[&Recipient], config_path: &Path) -> Result<String> {
         let p = config_path.join("share").join("ripasso").join("keys");
         std::fs::create_dir_all(&p)?;
 
