@@ -1,11 +1,17 @@
-use std::{io, path, string};
+use std::{
+    io, path, string,
+    sync::{Arc, Mutex, MutexGuard, PoisonError},
+};
 
 use hex::FromHexError;
 
+use crate::pass::PasswordStore;
+
 /// A enum that contains the different types of errors that the library returns as part of Result's.
 #[non_exhaustive]
 #[derive(Debug)]
 pub enum Error {
+    Clipboard(arboard::Error),
     Io(io::Error),
     Git(git2::Error),
     Gpg(gpgme::Error),
@@ -28,6 +34,12 @@ pub enum Error {
     SystemTimeError(std::time::SystemTimeError),
 }
 
+impl From<arboard::Error> for Error {
+    fn from(err: arboard::Error) -> Self {
+        Self::Clipboard(err)
+    }
+}
+
 impl From<io::Error> for Error {
     fn from(err: io::Error) -> Self {
         Self::Io(err)
@@ -169,9 +181,22 @@ impl From<std::time::SystemTimeError> for Error {
     }
 }
 
+impl From<PoisonError<MutexGuard<'_, Vec<Arc<Mutex<PasswordStore>>>>>> for Error {
+    fn from(_err: PoisonError<MutexGuard<'_, Vec<Arc<Mutex<PasswordStore>>>>>) -> Self {
+        Self::Generic("Error obtaining lock")
+    }
+}
+
+impl From<PoisonError<MutexGuard<'_, Arc<Mutex<PasswordStore>>>>> for Error {
+    fn from(_err: PoisonError<MutexGuard<'_, Arc<Mutex<PasswordStore>>>>) -> Self {
+        Self::Generic("Error obtaining lock")
+    }
+}
+
 impl std::fmt::Display for Error {
     fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
         match self {
+            Self::Clipboard(err) => write!(f, "{err}"),
             Self::Io(err) => write!(f, "{err}"),
             Self::Git(err) => write!(f, "{err}"),
             Self::Gpg(err) => write!(f, "{err}"),
