@@ -3,8 +3,7 @@
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
+    the Free Software Foundation, version 3 of the License.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -27,6 +26,7 @@ use std::{
 
 use chrono::prelude::*;
 use totp_rs::TOTP;
+use zeroize::Zeroize;
 
 use crate::{
     crypto::{Crypto, CryptoImpl, GpgMe, Sequoia, VerificationError},
@@ -62,6 +62,20 @@ pub struct PasswordStore {
     user_home: Option<PathBuf>,
 }
 
+impl Default for PasswordStore {
+    fn default() -> Self {
+        Self {
+            name: "default".to_owned(),
+            root: PathBuf::from("/tmp/"),
+            valid_gpg_signing_keys: vec![],
+            passwords: vec![],
+            style_file: None,
+            crypto: Box::new(GpgMe {}),
+            user_home: None,
+        }
+    }
+}
+
 impl PasswordStore {
     /// Constructs a `PasswordStore` object. If `password_store_signing_key` is present,
     /// the function verifies that the .gpg-id file is signed correctly
@@ -90,6 +104,7 @@ impl PasswordStore {
                 Box::new(Sequoia::new(
                     &home.join(".local"),
                     own_fingerprint.ok_or_else(|| Error::Generic("own_fingerprint is not configured, required for using Sequoia as pgp implementation"))?,
+                    &home,
                 )?)
             }
         };
@@ -107,7 +122,7 @@ impl PasswordStore {
         };
 
         if !store.valid_gpg_signing_keys.is_empty() {
-            store.verify_gpg_id_file()?;
+            store.verify_gpg_id_files()?;
         }
 
         Ok(store)
@@ -232,14 +247,49 @@ impl PasswordStore {
     }
 
     pub fn repo(&self) -> Result<git2::Repository> {
-        git2::Repository::open(&self.root).map_err(Error::Git)
+        Ok(git2::Repository::open(&self.root)?)
     }
 
-    fn verify_gpg_id_file(&self) -> Result<SignatureStatus> {
-        let mut gpg_id_file = self.root.clone();
-        gpg_id_file.push(".gpg-id");
-        let mut gpg_id_sig_file = self.root.clone();
-        gpg_id_sig_file.push(".gpg-id.sig");
+    fn verify_gpg_id_files(&self) -> Result<SignatureStatus> {
+        let mut result = SignatureStatus::Good;
+        for gpg_id_file in self.recipients_files()? {
+            let mut gpg_id_sig_file = self.root.clone();
+            gpg_id_sig_file.push(".gpg-id.sig");
+
+            let gpg_id = fs::read(gpg_id_file)?;
+            let gpg_id_sig =
+                match fs::read(gpg_id_sig_file) {
+                    Ok(c) => c,
+                    Err(_) => return Err(Error::Generic(
+                        "problem reading .gpg-id.sig, and strict signature checking was asked for",
+                    )),
+                };
+
+            match self.crypto.verify_sign(&gpg_id, &gpg_id_sig, &self.valid_gpg_signing_keys) {
+                Ok(r) => {
+                    match r {
+                        SignatureStatus::Good => {},
+                        SignatureStatus::AlmostGood => result = SignatureStatus::AlmostGood,
+                        SignatureStatus::Bad => return Ok(SignatureStatus::Bad)
+                    }
+                },
+                Err(VerificationError::InfrastructureError(message)) => return Err(Error::GenericDyn(message)),
+                Err(VerificationError::SignatureFromWrongRecipient) => return Err(Error::Generic("the .gpg-id file wasn't signed by one of the keys specified in the environmental variable PASSWORD_STORE_SIGNING_KEY")),
+                Err(VerificationError::BadSignature) => return Err(Error::Generic("Bad signature for .gpg-id file")),
+                Err(VerificationError::MissingSignatures) => return Err(Error::Generic("Missing signature for .gpg-id file, and PASSWORD_STORE_SIGNING_KEY specified")),
+                Err(VerificationError::TooManySignatures) => return Err(Error::Generic("Signature for .gpg-id file contained more than one signature, something is fishy")),
+            }
+        }
+        Ok(result)
+    }
+
+    fn verify_gpg_id_file_for_path(&self, path: &Path) -> Result<SignatureStatus> {
+        let gpg_id_file = self.recipients_file_for_dir(path)?;
+        let gpg_id_sig_file = {
+            let mut sig = gpg_id_file.clone();
+            sig.pop();
+            sig.join(".gpg-id.sig")
+        };
 
         let gpg_id = fs::read(gpg_id_file)?;
         let gpg_id_sig = match fs::read(gpg_id_sig_file) {
@@ -315,12 +365,10 @@ impl PasswordStore {
         let mut file = File::create(path)?;
 
         if !self.valid_gpg_signing_keys.is_empty() {
-            self.verify_gpg_id_file()?;
+            self.verify_gpg_id_files()?;
         }
 
-        let mut recipients_file = self.root.clone();
-        recipients_file.push(".gpg-id");
-        let recipients = self.all_recipients()?;
+        let recipients = self.recipients_for_path(path)?;
         let output = self.crypto.encrypt_string(content, &recipients)?;
 
         if let Err(why) = file.write_all(&output) {
@@ -506,39 +554,131 @@ impl PasswordStore {
     /// Returns an `Err` if the gpg_id file should be verified and it can't be
     pub fn all_recipients(&self) -> Result<Vec<Recipient>> {
         if !self.valid_gpg_signing_keys.is_empty() {
-            self.verify_gpg_id_file()?;
+            self.verify_gpg_id_files()?;
         }
 
-        Recipient::all_recipients(&self.recipients_file(), self.crypto.as_ref())
+        let mut recipients = vec![];
+        for file in self.recipients_files()? {
+            for r in Recipient::all_recipients(&file, self.crypto.as_ref())? {
+                if !recipients.contains(&r) {
+                    recipients.push(r);
+                }
+            }
+        }
+        Ok(recipients)
     }
 
-    fn recipients_file(&self) -> PathBuf {
-        let mut rf = self.root.clone();
-        rf.push(".gpg-id");
-        rf
-    }
-
-    /// Removes a key from the .gpg-id file and re-encrypts all the passwords
+    /// Return a list of all the Recipients in the `.gpg-id` file that is the
+    /// closest parent to `path`.
     /// # Errors
-    /// Returns an `Err` if the gpg_id file should be verified and it can't be or if the recipient is the last one.
-    pub fn remove_recipient(&self, r: &Recipient) -> Result<()> {
+    /// Returns an `Err` if the gpg_id file should be verified and it can't be
+    pub fn recipients_for_path(&self, path: &Path) -> Result<Vec<Recipient>> {
+        if !self.valid_gpg_signing_keys.is_empty() {
+            self.verify_gpg_id_file_for_path(path)?;
+        }
+
+        Recipient::all_recipients(&self.recipients_file_for_dir(path)?, self.crypto.as_ref())
+    }
+
+    fn recipients_file_for_dir(&self, path: &Path) -> Result<PathBuf> {
+        let mut new_dir = std::fs::canonicalize(self.root.join(path))?;
+
+        let root = std::fs::canonicalize(&self.root)?;
+
+        if !new_dir.starts_with(&root) {
+            return Err(Error::Generic("path traversal is not allowed"));
+        }
+
+        while new_dir.starts_with(&root) {
+            let f = new_dir.join(".gpg-id");
+
+            if f.exists() {
+                return Ok(f);
+            }
+            new_dir.pop();
+        }
+
+        Err(Error::Generic("No .gpg-id file found"))
+    }
+
+    fn visit_dirs(dir: &Path, result: &mut Vec<PathBuf>) -> Result<()> {
+        if dir.is_dir() {
+            for entry in fs::read_dir(dir)? {
+                let entry = entry?;
+                let path = entry.path();
+                if path.is_dir() {
+                    Self::visit_dirs(&path, result)?;
+                } else if entry.file_name() == ".gpg-id" {
+                    result.push(entry.path());
+                }
+            }
+        }
+        Ok(())
+    }
+
+    fn recipients_files(&self) -> Result<Vec<PathBuf>> {
+        let mut results = vec![];
+        Self::visit_dirs(&self.root, &mut results)?;
+        Ok(results)
+    }
+
+    fn remove_recipient_inner(&self, r: &Recipient, path: &Path) -> Result<()> {
         Recipient::remove_recipient_from_file(
             r,
-            &self.recipients_file(),
+            &self.recipients_file_for_dir(path)?,
+            &self.root,
             &self.valid_gpg_signing_keys,
             self.crypto.as_ref(),
         )?;
         self.reencrypt_all_password_entries()
     }
 
-    /// Adds a key to the .gpg-id file and re-encrypts all the passwords
+    /// Removes a key from the .gpg-id file and re-encrypts all the passwords
+    /// # Errors
+    /// Returns an `Err` if the gpg_id file should be verified and it can't be or if the recipient is the last one.
+    pub fn remove_recipient(&self, r: &Recipient, path: &Path) -> Result<()> {
+        let gpg_id_file = &self.recipients_file_for_dir(path)?;
+        let gpg_id_file_content = std::fs::read_to_string(gpg_id_file)?;
+
+        let res = self.remove_recipient_inner(r, path);
+
+        if res.is_err() {
+            std::fs::write(gpg_id_file, gpg_id_file_content)?;
+        }
+        res
+    }
+
+    /// Adds a key to the .gpg-id file in the path directory and re-encrypts all the passwords
     /// # Errors
     /// Returns an `Err` if the gpg_id file should be verified and it can't be or there is some problem with
     /// the encryption.
-    pub fn add_recipient(&self, r: &Recipient) -> Result<()> {
+    pub fn add_recipient(&mut self, r: &Recipient, path: &Path, config_path: &Path) -> Result<()> {
+        if !self.crypto.is_key_in_keyring(r)? {
+            self.crypto.pull_keys(&[r], config_path)?;
+        }
+        if !self.crypto.is_key_in_keyring(r)? {
+            return Err(Error::Generic(
+                "Key isn't in keyring and couldn't be downloaded from keyservers",
+            ));
+        }
+
+        let dir = self.root.join(path);
+        if !dir.exists() {
+            return Err(Error::Generic("path doesn't exist"));
+        }
+        let dir = std::fs::canonicalize(self.root.join(path))?;
+        let root = std::fs::canonicalize(&self.root)?;
+
+        if !dir.starts_with(root) {
+            return Err(Error::Generic("path traversal not allowed"));
+        }
+        if !dir.join(".gpg-id").exists() {
+            std::fs::File::create(dir.join(".gpg-id"))?;
+        }
+
         Recipient::add_recipient_to_file(
             r,
-            &self.recipients_file(),
+            &self.recipients_file_for_dir(path)?,
             &self.valid_gpg_signing_keys,
             self.crypto.as_ref(),
         )?;
@@ -553,7 +693,9 @@ impl PasswordStore {
     fn reencrypt_all_password_entries(&self) -> Result<()> {
         let mut names: Vec<PathBuf> = Vec::new();
         for entry in self.all_passwords()? {
-            entry.update_internal(&entry.secret(self)?, self)?;
+            let mut secret = entry.secret(self)?;
+            entry.update_internal(&secret, self)?;
+            secret.zeroize();
             names.push(append_extension(PathBuf::from(&entry.name), ".gpg"));
         }
         names.push(PathBuf::from(".gpg-id"));
@@ -565,8 +707,12 @@ impl PasswordStore {
         let keys = self
             .all_recipients()?
             .into_iter()
-            .map(|s| format!("0x{}, ", s.key_id))
-            .collect::<String>();
+            .fold(String::new(), |mut acc, r| {
+                use std::fmt::Write;
+                let _ = write!(acc, ", 0x{}", r.key_id);
+                acc
+            });
+
         let message = format!("Reencrypt password store with new GPG ids {keys}");
 
         self.add_and_commit(&names, &message)?;
@@ -641,7 +787,15 @@ impl PasswordStore {
         new_path_dir.pop();
         fs::create_dir_all(&new_path_dir)?;
 
-        fs::rename(&old_path, &new_path)?;
+        let mut file = std::fs::File::create(&new_path)?;
+        let mut secret = self.crypto.decrypt_string(&std::fs::read(&old_path)?)?;
+        let new_recipients = Recipient::all_recipients(
+            &self.recipients_file_for_dir(&new_path)?,
+            self.crypto.as_ref(),
+        )?;
+        file.write_all(&self.crypto.encrypt_string(&secret, &new_recipients)?)?;
+        secret.zeroize();
+        std::fs::remove_file(&old_path)?;
 
         if self.repo().is_ok() {
             let old_file_name = append_extension(PathBuf::from(old_name), ".gpg");
@@ -737,7 +891,7 @@ impl GitLogLine {
 }
 
 /// The state of a password, with regards to git
-#[derive(Clone, Debug, PartialEq, Eq)]
+#[derive(Clone, Debug, PartialEq, Eq, Default)]
 #[non_exhaustive]
 pub enum RepositoryStatus {
     /// The password is in git
@@ -745,16 +899,17 @@ pub enum RepositoryStatus {
     /// The password isn't in git
     NotInRepo,
     /// The passwordstore isn't backed by a git repo
+    #[default]
     NoRepo,
 }
 
 /// One password in the password store
-#[derive(Clone, Debug)]
+#[derive(Clone, Debug, Default)]
 pub struct PasswordEntry {
     /// Name of the entry, (from relative path to password)
     pub name: String,
     /// Absolute path to the password file
-    path: PathBuf,
+    pub path: PathBuf,
     /// if we have a git repo, then commit time
     pub updated: Option<DateTime<Local>>,
     /// if we have a git repo, then the name of the committer
@@ -863,14 +1018,17 @@ impl PasswordEntry {
     /// # Errors
     /// Returns an `Err` if the decryption fails
     pub fn password(&self, store: &PasswordStore) -> Result<String> {
-        Ok(self.secret(store)?.split('\n').take(1).collect())
+        let mut secret = self.secret(store)?;
+        let password: String = secret.split('\n').take(1).collect();
+        secret.zeroize();
+        Ok(password)
     }
 
     /// decrypts and returns a TOTP code if the entry contains a otpauth:// url
     /// # Errors
     /// Returns an `Err` if the code generation fails
     pub fn mfa(&self, store: &PasswordStore) -> Result<String> {
-        let secret = self.secret(store)?;
+        let mut secret = self.secret(store)?;
 
         if let Some(start_pos) = secret.find("otpauth://") {
             let end_pos = {
@@ -884,18 +1042,21 @@ impl PasswordEntry {
                 end_pos
             };
             let totp = TOTP::from_url(&secret[start_pos..end_pos])?;
+            secret.zeroize();
             Ok(totp.generate_current()?)
         } else {
+            secret.zeroize();
             Err(Error::Generic("No otpauth:// url in secret"))
         }
     }
 
+    /// All calls to this function must be followed by secret.zeroize()
     fn update_internal(&self, secret: &str, store: &PasswordStore) -> Result<()> {
         if !store.valid_gpg_signing_keys.is_empty() {
-            store.verify_gpg_id_file()?;
+            store.verify_gpg_id_files()?;
         }
 
-        let recipients = store.all_recipients()?;
+        let recipients = store.recipients_for_path(&self.path)?;
         let ciphertext = store.crypto.encrypt_string(secret, &recipients)?;
 
         let mut output = File::create(&self.path)?;
@@ -907,8 +1068,9 @@ impl PasswordEntry {
     /// is supplied.
     /// # Errors
     /// Returns an `Err` if the update fails.
-    pub fn update(&self, secret: String, store: &PasswordStore) -> Result<()> {
+    pub fn update(&self, mut secret: String, store: &PasswordStore) -> Result<()> {
         self.update_internal(&secret, store)?;
+        secret.zeroize();
 
         if store.repo().is_err() {
             return Ok(());
@@ -1017,8 +1179,9 @@ impl PasswordEntry {
 /// Returns an `Err` if the download fails
 pub fn pgp_pull(store: &mut PasswordStore, config_path: &Path) -> Result<String> {
     let recipients = store.all_recipients()?;
+    let recipients_refs: Vec<&Recipient> = recipients.iter().collect();
 
-    let result = store.crypto.pull_keys(&recipients, config_path)?;
+    let result = store.crypto.pull_keys(&recipients_refs, config_path)?;
 
     Ok(result)
 }
