@@ -25,12 +25,10 @@ fn test_parse_signing_keys_two_keys() {
     let result = parse_signing_keys(&Some(file_content), &crypto).unwrap();
 
     assert_eq!(2, result.len());
-    assert_eq!(
-        true,
+    assert!(
         result.contains(&<[u8; 20]>::from_hex("7E068070D5EF794B00C8A9D91D108E6C07CBC406").unwrap())
     );
-    assert_eq!(
-        true,
+    assert!(
         result.contains(&<[u8; 20]>::from_hex("E6A7D758338EC2EF2A8A9F4EE7E3DB4B3217482F").unwrap())
     );
 }
@@ -54,12 +52,10 @@ fn test_parse_signing_keys_two_keys_with_0x() {
     let result = parse_signing_keys(&Some(file_content), &crypto).unwrap();
 
     assert_eq!(2, result.len());
-    assert_eq!(
-        true,
+    assert!(
         result.contains(&<[u8; 20]>::from_hex("7E068070D5EF794B00C8A9D91D108E6C07CBC406").unwrap())
     );
-    assert_eq!(
-        true,
+    assert!(
         result.contains(&<[u8; 20]>::from_hex("E6A7D758338EC2EF2A8A9F4EE7E3DB4B3217482F").unwrap())
     );
 }
@@ -74,7 +70,7 @@ fn parse_signing_keys_key_error() {
 
     let result = parse_signing_keys(&Some(file_content), &crypto);
 
-    assert_eq!(true, result.is_err());
+    assert!(result.is_err());
 }
 
 #[test]
@@ -92,7 +88,7 @@ fn parse_signing_keys_short() {
 
     let result = parse_signing_keys(&Some("0x1D108E6C07CBC406".to_string()), &crypto);
 
-    assert_eq!(true, result.is_err());
+    assert!(result.is_err());
 }
 
 #[test]
@@ -101,7 +97,7 @@ fn recipient_from_key_error() {
 
     let result = Recipient::from("0x1D108E6C07CBC406", &[], None, &crypto);
 
-    assert_eq!(false, result.is_err());
+    assert!(result.is_ok());
     let result = result.unwrap();
     assert_eq!("key id not in keyring", result.name);
 }
@@ -130,7 +126,7 @@ fn all_recipients() {
         result[0].name
     );
     assert_eq!("0x1D108E6C07CBC406", result[0].key_id);
-    assert_eq!(true, KeyRingStatus::InKeyRing == result[0].key_ring_status);
+    assert!(KeyRingStatus::InKeyRing == result[0].key_ring_status);
 }
 
 #[test]
@@ -162,7 +158,7 @@ fn all_recipients_with_one_comment_line() {
     );
     assert_eq!(None, result[0].comment.post_comment);
     assert_eq!("0x1D108E6C07CBC406", result[0].key_id);
-    assert_eq!(true, KeyRingStatus::InKeyRing == result[0].key_ring_status);
+    assert!(KeyRingStatus::InKeyRing == result[0].key_ring_status);
 }
 
 #[test]
@@ -198,7 +194,7 @@ fn all_recipients_with_multiple_comment_lines() {
     );
     assert_eq!(None, result[0].comment.post_comment);
     assert_eq!("0x1D108E6C07CBC406", result[0].key_id);
-    assert_eq!(true, KeyRingStatus::InKeyRing == result[0].key_ring_status);
+    assert!(KeyRingStatus::InKeyRing == result[0].key_ring_status);
 }
 
 #[test]
@@ -233,7 +229,7 @@ fn all_recipients_with_comment_lines_pre_and_post() {
         result[0].comment.pre_comment.as_ref().unwrap()
     );
     assert_eq!("0x1D108E6C07CBC406", result[0].key_id);
-    assert_eq!(true, KeyRingStatus::InKeyRing == result[0].key_ring_status);
+    assert!(KeyRingStatus::InKeyRing == result[0].key_ring_status);
 }
 
 #[test]
@@ -251,10 +247,7 @@ fn all_recipients_error() {
     assert_eq!(1, result.len());
     assert_eq!("key id not in keyring", result[0].name);
     assert_eq!("0x1D108E6C07CBC406", result[0].key_id);
-    assert_eq!(
-        true,
-        KeyRingStatus::NotInKeyRing == result[0].key_ring_status
-    );
+    assert!(KeyRingStatus::NotInKeyRing == result[0].key_ring_status);
 }
 
 #[test]
@@ -266,7 +259,7 @@ fn all_recipients_no_file_error() {
 
     let result = Recipient::all_recipients(&file, &crypto);
 
-    assert_eq!(true, result.is_err());
+    assert!(result.is_err());
 }
 
 #[test]
@@ -281,8 +274,8 @@ fn write_recipients_file_empty() {
 
     let crypto = MockCrypto::new();
 
-    assert_eq!(false, recipients_file.exists());
-    assert_eq!(false, signature_file.exists());
+    assert!(!recipients_file.exists());
+    assert!(!signature_file.exists());
 
     let result = Recipient::write_recipients_file(
         &recipients,
@@ -291,13 +284,13 @@ fn write_recipients_file_empty() {
         &crypto,
     );
 
-    assert_eq!(false, result.is_err());
-    assert_eq!(true, recipients_file.exists());
-    assert_eq!(false, recipients_file.join(".sig").exists());
+    assert!(result.is_ok());
+    assert!(recipients_file.exists());
+    assert!(!recipients_file.join(".sig").exists());
 
     let contents = std::fs::read_to_string(recipients_file).unwrap();
     assert_eq!("", contents);
-    assert_eq!(false, signature_file.exists());
+    assert!(!signature_file.exists());
 }
 
 #[test]
@@ -312,8 +305,8 @@ fn write_recipients_file_one() {
 
     let crypto = MockCrypto::new();
 
-    assert_eq!(false, recipients_file.exists());
-    assert_eq!(false, signature_file.exists());
+    assert!(!recipients_file.exists());
+    assert!(!signature_file.exists());
 
     let result = Recipient::write_recipients_file(
         &recipients,
@@ -322,16 +315,16 @@ fn write_recipients_file_one() {
         &crypto,
     );
 
-    assert_eq!(false, result.is_err());
-    assert_eq!(true, recipients_file.exists());
+    assert!(result.is_ok());
+    assert!(recipients_file.exists());
 
     let recipient_sig_filename = append_file_name(&recipients_file);
 
-    assert_eq!(false, recipient_sig_filename.exists());
+    assert!(!recipient_sig_filename.exists());
 
     let contents = std::fs::read_to_string(recipients_file).unwrap();
     assert_eq!("0x7E068070D5EF794B00C8A9D91D108E6C07CBC406\n", contents);
-    assert_eq!(false, signature_file.exists());
+    assert!(!signature_file.exists());
 }
 
 #[test]
@@ -351,8 +344,8 @@ fn write_recipients_file_one_with_pre_comment() {
 
     let crypto = MockCrypto::new();
 
-    assert_eq!(false, recipients_file.exists());
-    assert_eq!(false, signature_file.exists());
+    assert!(!recipients_file.exists());
+    assert!(!signature_file.exists());
 
     let result = Recipient::write_recipients_file(
         &recipients,
@@ -361,19 +354,19 @@ fn write_recipients_file_one_with_pre_comment() {
         &crypto,
     );
 
-    assert_eq!(false, result.is_err());
-    assert_eq!(true, recipients_file.exists());
+    assert!(result.is_ok());
+    assert!(recipients_file.exists());
 
     let recipient_sig_filename = append_file_name(&recipients_file);
 
-    assert_eq!(false, recipient_sig_filename.exists());
+    assert!(!recipient_sig_filename.exists());
 
     let contents = std::fs::read_to_string(recipients_file).unwrap();
     assert_eq!(
         "#comment line\n0x7E068070D5EF794B00C8A9D91D108E6C07CBC406\n",
         contents
     );
-    assert_eq!(false, signature_file.exists());
+    assert!(!signature_file.exists());
 }
 
 #[test]
@@ -393,8 +386,8 @@ fn write_recipients_file_one_with_multi_line_comment() {
 
     let crypto = MockCrypto::new();
 
-    assert_eq!(false, recipients_file.exists());
-    assert_eq!(false, signature_file.exists());
+    assert!(!recipients_file.exists());
+    assert!(!signature_file.exists());
 
     let result = Recipient::write_recipients_file(
         &recipients,
@@ -403,19 +396,19 @@ fn write_recipients_file_one_with_multi_line_comment() {
         &crypto,
     );
 
-    assert_eq!(false, result.is_err());
-    assert_eq!(true, recipients_file.exists());
+    assert!(result.is_ok());
+    assert!(recipients_file.exists());
 
     let recipient_sig_filename = append_file_name(&recipients_file);
 
-    assert_eq!(false, recipient_sig_filename.exists());
+    assert!(!recipient_sig_filename.exists());
 
     let contents = std::fs::read_to_string(recipients_file).unwrap();
     assert_eq!(
         "#comment one\n#comment two\n0x7E068070D5EF794B00C8A9D91D108E6C07CBC406\n",
         contents
     );
-    assert_eq!(false, signature_file.exists());
+    assert!(!signature_file.exists());
 }
 
 #[test]
@@ -435,8 +428,8 @@ fn write_recipients_file_one_comment_pre_and_post() {
 
     let crypto = MockCrypto::new();
 
-    assert_eq!(false, recipients_file.exists());
-    assert_eq!(false, signature_file.exists());
+    assert!(!recipients_file.exists());
+    assert!(!signature_file.exists());
 
     let result = Recipient::write_recipients_file(
         &recipients,
@@ -445,19 +438,19 @@ fn write_recipients_file_one_comment_pre_and_post() {
         &crypto,
     );
 
-    assert_eq!(false, result.is_err());
-    assert_eq!(true, recipients_file.exists());
+    assert!(result.is_ok());
+    assert!(recipients_file.exists());
 
     let recipient_sig_filename = append_file_name(&recipients_file);
 
-    assert_eq!(false, recipient_sig_filename.exists());
+    assert!(!recipient_sig_filename.exists());
 
     let contents = std::fs::read_to_string(recipients_file).unwrap();
     assert_eq!(
         "#pre comment\n0x7E068070D5EF794B00C8A9D91D108E6C07CBC406 #post comment\n",
         contents
     );
-    assert_eq!(false, signature_file.exists());
+    assert!(!signature_file.exists());
 }
 
 #[test]
@@ -473,8 +466,8 @@ fn write_recipients_file_one_and_signed() {
 
     let crypto = MockCrypto::new().with_sign_string_return("unit test sign string".to_owned());
 
-    assert_eq!(false, recipients_file.exists());
-    assert_eq!(false, signature_file.exists());
+    assert!(!recipients_file.exists());
+    assert!(!signature_file.exists());
 
     let result = Recipient::write_recipients_file(
         &recipients,
@@ -483,17 +476,17 @@ fn write_recipients_file_one_and_signed() {
         &crypto,
     );
 
-    assert_eq!(false, result.is_err());
-    assert_eq!(true, recipients_file.exists());
+    assert!(result.is_ok());
+    assert!(recipients_file.exists());
 
     let recipient_sig_filename = append_file_name(&recipients_file);
 
-    assert_eq!(true, recipient_sig_filename.exists());
+    assert!(recipient_sig_filename.exists());
 
     let contents = std::fs::read_to_string(recipients_file).unwrap();
     assert_eq!("0x7E068070D5EF794B00C8A9D91D108E6C07CBC406\n", contents);
 
-    assert_eq!(true, signature_file.exists());
+    assert!(signature_file.exists());
     let contents = std::fs::read_to_string(&signature_file).unwrap();
     assert_eq!("unit test sign string", contents);
 }
@@ -511,8 +504,8 @@ fn remove_recipient_from_file_last() {
 
     let crypto = MockCrypto::new();
 
-    assert_eq!(false, recipients_file.exists());
-    assert_eq!(false, signature_file.exists());
+    assert!(!recipients_file.exists());
+    assert!(!signature_file.exists());
 
     let result = Recipient::write_recipients_file(
         &recipients,
@@ -520,21 +513,22 @@ fn remove_recipient_from_file_last() {
         &valid_gpg_signing_keys,
         &crypto,
     );
-    assert_eq!(false, result.is_err());
+    assert!(result.is_ok());
     let contents = std::fs::read_to_string(&recipients_file).unwrap();
     assert_eq!("0x7E068070D5EF794B00C8A9D91D108E6C07CBC406\n", contents);
 
     let result = Recipient::remove_recipient_from_file(
         &r,
         &recipients_file,
+        dir.path(),
         &valid_gpg_signing_keys,
         &crypto,
     );
-    assert_eq!(false, result.is_err());
+    assert!(result.is_ok());
 
     let contents = std::fs::read_to_string(&recipients_file).unwrap();
     assert_eq!("0x7E068070D5EF794B00C8A9D91D108E6C07CBC406\n", contents);
-    assert_eq!(false, signature_file.exists());
+    assert!(!signature_file.exists());
 }
 
 #[test]
@@ -559,8 +553,8 @@ fn remove_recipient_from_file_two() {
             MockKey::from_args(r2.fingerprint.unwrap(), vec![r2.name.clone()]),
         );
 
-    assert_eq!(false, recipients_file.exists());
-    assert_eq!(false, signature_file.exists());
+    assert!(!recipients_file.exists());
+    assert!(!signature_file.exists());
 
     let result = Recipient::write_recipients_file(
         &recipients,
@@ -568,7 +562,7 @@ fn remove_recipient_from_file_two() {
         &valid_gpg_signing_keys,
         &crypto,
     );
-    assert_eq!(false, result.is_err());
+    assert!(result.is_ok());
     let contents = std::fs::read_to_string(&recipients_file).unwrap();
     assert_eq!(
         "0x7E068070D5EF794B00C8A9D91D108E6C07CBC406\n0xDB07DAC5B3882EAB659E1D2FDF0C3D316B7312D5\n",
@@ -578,22 +572,17 @@ fn remove_recipient_from_file_two() {
     let result = Recipient::remove_recipient_from_file(
         &r,
         &recipients_file,
+        dir.path(),
         &valid_gpg_signing_keys,
         &crypto,
     );
-    assert_eq!(false, result.is_err());
+    assert!(result.is_ok());
 
     let contents = std::fs::read_to_string(&recipients_file).unwrap();
     assert_eq!(86, contents.len());
-    assert_eq!(
-        true,
-        contents.contains("0xDB07DAC5B3882EAB659E1D2FDF0C3D316B7312D5")
-    );
-    assert_eq!(
-        true,
-        contents.contains("0x7E068070D5EF794B00C8A9D91D108E6C07CBC406")
-    );
-    assert_eq!(false, signature_file.exists());
+    assert!(contents.contains("0xDB07DAC5B3882EAB659E1D2FDF0C3D316B7312D5"));
+    assert!(contents.contains("0x7E068070D5EF794B00C8A9D91D108E6C07CBC406"));
+    assert!(!signature_file.exists());
 }
 
 #[test]
@@ -651,8 +640,8 @@ fn remove_recipient_from_file_same_key_id_different_fingerprint() {
             ),
         );
 
-    assert_eq!(false, recipients_file.exists());
-    assert_eq!(false, signature_file.exists());
+    assert!(!recipients_file.exists());
+    assert!(!signature_file.exists());
 
     let result = Recipient::write_recipients_file(
         &recipients,
@@ -660,7 +649,7 @@ fn remove_recipient_from_file_same_key_id_different_fingerprint() {
         &valid_gpg_signing_keys,
         &crypto,
     );
-    assert_eq!(false, result.is_err());
+    assert!(result.is_ok());
     let contents = std::fs::read_to_string(&recipients_file).unwrap();
     assert_eq!(
         "0x88283D2EF664DD5F6AEBB51CDF0C3D316B7312D5\n0xDB07DAC5B3882EAB659E1D2FDF0C3D316B7312D5\n",
@@ -670,18 +659,16 @@ fn remove_recipient_from_file_same_key_id_different_fingerprint() {
     let result = Recipient::remove_recipient_from_file(
         &r,
         &recipients_file,
+        dir.path(),
         &valid_gpg_signing_keys,
         &crypto,
     );
-    assert_eq!(false, result.is_err());
+    assert!(result.is_ok());
 
     let contents = std::fs::read_to_string(&recipients_file).unwrap();
     assert_eq!(43, contents.len());
-    assert_eq!(
-        true,
-        contents.contains("0x88283D2EF664DD5F6AEBB51CDF0C3D316B7312D5")
-    );
-    assert_eq!(false, signature_file.exists());
+    assert!(contents.contains("0x88283D2EF664DD5F6AEBB51CDF0C3D316B7312D5"));
+    assert!(!signature_file.exists());
 }
 
 #[test]
@@ -706,8 +693,8 @@ fn add_recipient_from_file_one_plus_one() {
             MockKey::from_args(r2.fingerprint.unwrap(), vec![r2.name.clone()]),
         );
 
-    assert_eq!(false, recipients_file.exists());
-    assert_eq!(false, signature_file.exists());
+    assert!(!recipients_file.exists());
+    assert!(!signature_file.exists());
 
     let result = Recipient::write_recipients_file(
         &recipients,
@@ -715,11 +702,11 @@ fn add_recipient_from_file_one_plus_one() {
         &valid_gpg_signing_keys,
         &crypto,
     );
-    assert_eq!(false, result.is_err());
+    assert!(result.is_ok());
 
     let result =
         Recipient::add_recipient_to_file(&r2, &recipients_file, &valid_gpg_signing_keys, &crypto);
-    assert_eq!(false, result.is_err());
+    assert!(result.is_ok());
 
     let contents = std::fs::read_to_string(&recipients_file).unwrap();
     assert_eq!(
@@ -730,22 +717,17 @@ fn add_recipient_from_file_one_plus_one() {
     let result = Recipient::remove_recipient_from_file(
         &r,
         &recipients_file,
+        dir.path(),
         &valid_gpg_signing_keys,
         &crypto,
     );
-    assert_eq!(false, result.is_err());
+    assert!(result.is_ok());
 
     let contents = std::fs::read_to_string(&recipients_file).unwrap();
     assert_eq!(86, contents.len());
-    assert_eq!(
-        true,
-        contents.contains("0xDB07DAC5B3882EAB659E1D2FDF0C3D316B7312D5")
-    );
-    assert_eq!(
-        true,
-        contents.contains("0x7E068070D5EF794B00C8A9D91D108E6C07CBC406")
-    );
-    assert_eq!(false, signature_file.exists());
+    assert!(contents.contains("0xDB07DAC5B3882EAB659E1D2FDF0C3D316B7312D5"));
+    assert!(contents.contains("0x7E068070D5EF794B00C8A9D91D108E6C07CBC406"));
+    assert!(!signature_file.exists());
 }
 
 #[test]
@@ -775,10 +757,8 @@ fn recipient_both_none() {
         not_usable: false,
     };
 
-    assert_eq!(false, r1 == r2);
-    assert_eq!(false, r2 == r1);
-    assert_eq!(true, r1 != r2);
-    assert_eq!(true, r2 != r1);
+    assert!(r1 != r2);
+    assert!(r2 != r1);
 }
 
 #[test]
@@ -810,10 +790,8 @@ fn recipient_one_none() {
         not_usable: false,
     };
 
-    assert_eq!(false, r1 == r2);
-    assert_eq!(false, r2 == r1);
-    assert_eq!(true, r1 != r2);
-    assert_eq!(true, r2 != r1);
+    assert!(r1 != r2);
+    assert!(r2 != r1);
 }
 
 #[test]
@@ -847,8 +825,6 @@ fn recipient_same_fingerprint_different_key_id() {
         not_usable: false,
     };
 
-    assert_eq!(true, r1 == r2);
-    assert_eq!(true, r2 == r1);
-    assert_eq!(false, r1 != r2);
-    assert_eq!(false, r2 != r1);
+    assert!(r1 == r2);
+    assert!(r2 == r1);
 }
